==> mgb-0.5.3-de.zip: mgb-0.5.3-de/deactivate.php <==
<?
         // MGB v.null.fnf (C) by Jrgen Grneisl
         //
         // This Guestbook is licensed under GNU GPL. Feel free to use, copy, share or modify it. :)

         include "settings.php";
         include "language/lang_admin.php";
         include "language/lang_main.php";

         if($_GET[sn]==""){$_GET[sn]=1;}

if($_GET[sid]!=$settings['passwort'])
        	{
         $ausgabe="<br>\n";
         $ausgabe.="<br>\n";
         $ausgabe.="<center>\n";
         $ausgabe.="<table summary='deaktivieren' class='passwort' cellspacing='0' cellpadding='5'>\n";
         $ausgabe.="<tr>\n";
         $ausgabe.="<td class='passworteingabetitel' style='height:20px'><font class='passworteingabetitel'>".$lang['failure']."</font></td>\n";
         $ausgabe.="</tr>\n";
         $ausgabe.="<tr>\n";
         $ausgabe.="<td class='passworteingabe'>\n";
         $ausgabe.="<center>\n";
         if($_POST[passwort]!="")
         	{
                 $ausgabe.="<br><font class='passwort_fehler'><b>".$lang['changed_pw']."</b></font><br><br>";
                 }
         else
         	{
         	$ausgabe.="<br><font class='passwort_fehler'><b>".$lang['not_logged_in']."</b></font><br><br>";
                 }
         $ausgabe.="</center>\n";
         $ausgabe.="</td>\n";
         $ausgabe.="</tr>\n";
         $ausgabe.="</table>\n";
         $ausgabe.="<br>\n";
         $ausgabe.="<br>\n";
         $ausgabe.="</center>\n";
         $anzeige[0]=$ausgabe;
         }
else
	{
         include "config.php";

         if($_GET[action]=="deactivate")
         	{
                 $sql="UPDATE `$db[entrys]` SET `checked` = '-1' WHERE ID=".$_GET[id]." LIMIT 1";
                 $link=mysql_connect($db[host], $db[user], $db[password]);
                 mysql_select_db($db[dbname], $link);
        		mysql_query($sql, $link);
                 }

         // Auslesen der vorhandenen Eintr&auml;ge
         $sql="SELECT * FROM $db[entrys] WHERE checked=1 ORDER BY ID DESC";
         $link=mysql_connect($db[host], $db[user], $db[password]);
         mysql_select_db($db[dbname], $link);
         $result=mysql_query($sql, $link);

         for($i=0;$i<mysql_num_rows($result);$i++)
         	{
		$eintrag[$i]=mysql_fetch_array($result);
		}

         $zaehler2=0;
         for($i=0;$i<count($eintrag);$i++)
         	{
                 $ausgabe="";
                	$ausgabe.="<br>\n<table summary='deaktivieren' cellspacing='0' cellpadding='3'>\n";
                	$ausgabe.="<tr>\n<td style='width:3%'><font><b>".$eintrag[$i][ID]."</b></font></td>\n";
                	$ausgabe.="<td style='width:57%;vertical-align:middle'><b><font>&nbsp;".$eintrag[$i][name];
                 if($eintrag[$i][place])
                 	{
                         $ausgabe.="&nbsp;".$lang['from']."&nbsp;".$eintrag[$i][place];
                         }
                 $ausgabe.="</font></b></td>\n<td align='right'><font>".$eintrag[$i][date]."&nbsp;".$lang['between_date_and_time']."&nbsp;".$eintrag[$i][time]."&nbsp;".$lang['time']."</font></td>\n</tr>\n";
                 $ausgabe.="<tr>\n<td colspan='3'><font>".$eintrag[$i][message]."</font></td>\n</tr>\n";
		$ausgabe.="<tr>\n<td colspan='3'>";
                 if($eintrag[$i][email])
                 	{
                         $ausgabe.="&nbsp;<a href='mailto:".$eintrag[$i][email]."'><img src='images/mail.png' border='0' alt='".$lang['alt_email_before_name']." ".$eintrag[$i][name]." ".$lang['alt_email_after_name']."' title='".$lang['alt_email_before_name']." ".$eintrag[$i][name]." ".$lang['alt_email_after_name']."'></a>\n";
                         }
                 if(strstr($eintrag[$i][hp],'http://'))
                 	{
                         $ausgabe.="&nbsp;<a href='".$eintrag[$i][hp]."' target='_blank'><img src='images/hp.png' border='0' alt='".$lang['alt_homepage_before_name']." ".$eintrag[$i][name]." ".$lang['alt_homepage_after_name']."' title='".$lang['alt_homepage_before_name']." ".$eintrag[$i][name]." ".$lang['alt_homepage_after_name']."'></a>\n";
                         }
                 if($eintrag[$i][icq]>=1)
                 	{
                         $ausgabe.="&nbsp;<a href='http://www.icq.com/".$eintrag[$i][icq]."' target='_blank'><img alt='ICQ# ".$eintrag[$i][icq]."' title='ICQ# ".$eintrag[$i][icq]."' style='height:15px;width:16px;border:none' src='images/icq.png'></a>\n";
                         }
                 if($eintrag[$i][aim])
                 	{
                         $ausgabe.="&nbsp;<a href='aim:goim?screenname=".$eintrag[$i][aim]."&amp;message=Hello+Are+you+there?' target='_blank'><img alt='AIM ".$eintrag[$i][aim]."' title='AIM ".$eintrag[$i][aim]."' style='height:15px;width:15px;border:none' src='images/aim.png'></a>\n";
                         }
                 if($eintrag[$i][msn])
                 	{
                         $ausgabe.="&nbsp;<a href='http://members.msn.com/?mem=".$eintrag[$i][msn]."' target='_blank'><img alt='MSN ".$eintrag[$i][msn]."' title='MSN ".$eintrag[$i][msn]."' style='height:15px;width:15px;border:none' src='images/msn.png'></a>\n";
                         }
                 $ausgabe.="&nbsp;&nbsp;<font><b>IP:&nbsp;".$eintrag[$i][ip]."</b></font></td>\n</tr>\n";
                 $ausgabe.="<tr>\n<td style='height:15px' colspan='3'>&nbsp;<font>&raquo;&nbsp;<a href='".$PHP_SELF."?action=deactivate&amp;id=".$eintrag[$i][ID]."&amp;sid=".$_GET[sid]."'>".$lang['deactivate_entry']."</a></font></td>\n</tr>\n";
                 $ausgabe.="</table><br>\n";
                 $anzeige[$zaehler2++]=$ausgabe;
                 }

         $seitenzahl=ceil($zaehler2/10);        // Anzahl der Seiten feststellen

         if($zaehler2>10)        // Wenn weniger oder gleich 10 Eintr&auml;ge im G&auml;stebuch sind, keine Links anzeigen
         	{
                 for($szahl=1;$szahl<=$seitenzahl;$szahl++)
                 	{
                         if($_GET[sn]==$szahl)
                         	{
                                 $seitenanzeige.="$szahl | ";        // Auf der angezeigten Seite die Nummer nicht als Link darstellen
                                 }
                         else
                         	{
                                 $seitenanzeige.="<a href='".$PHP_SELF."?sn=".$szahl."&amp;sid=".$_GET[sid]."'>".$szahl."</a> | ";	// Alle anderen Seiten als Link darstellen
                                 }
                         }
                 }
         }
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<title>Administration - guestbook v.null.f&uuml;nf by mopzz.de</title>
<meta name="author" content="mopzz">
<meta name="keywords" content="mgb.v.null.fuenf, mopzz.de, kostenloses g&auml;stebuch, kostenloses php g&auml;stebuch">
<meta http-equiv="content-type" content="text/html; charset=ISO-8859-1">
<link rel="stylesheet" type="text/css" href="css/activate.css">
</head>
<body>
<center>
<?php
         if($_GET[sid]==$settings['passwort'])
         	{
         	echo "<font><b>".$zaehler2." ".$lang['active_entries']."</b></font><br>";
                 }

	if($zaehler2>10)        // Wenn weniger als 10 Eintr&auml;ge angezeigt werden, keine Seitenanzeige darstellen. Man w&uuml;rde sonst das | alleine sehen.
                 {
                 echo "<br><center><font>| ".$seitenanzeige."</font></center>";
                 }

         if(!$_GET[sn])	// Wenn nur guestbook.php ohne ?sn=$szahl aufgerufen wird, den Startwert auf 0 setzen
                 {
                 $startwert=0;
                 }
         elseif($_GET[sn]==1)	// Wenn die erste Seite angezeigt wird, den Startwert ebenfalls auf 0 setzen
                 {
                 $startwert=0;
                 }
         else			// Wenn "sn" nicht 1 ist, den Wert mit 10 multiplizieren und 10 abziehen um vom ersten Eintrag in diesem Datensatz aus zu starten.
                 {
                 $startwert=(($_GET[sn]*10)-10);
                 }
         for($zahl=$startwert;$zahl<=($startwert+9);$zahl++)	// vom ersten Eintrag bis zum letzten in diesem Datensatz hochz&auml;hlen und ausgeben
                 {
                 echo $anzeige[$zahl];
                 }
         if($zaehler2>10)	// Wenn weniger als 10 Eintr&auml;ge angezeigt werden, keine Seitenanzeige darstellen. Man w&uuml;rde sonst das | alleine sehen.
                 {
                 echo "<br><center><font>| ".$seitenanzeige."</font></center>";
                 }
?>
</center>
</body>
</html>

==> mgb-0.5.4-de.zip: mgb-0.5.4-de/deactivate.php <==
<?
// DO NOT REMOVE THIS COPYRIGHT //
//
// MGB v.null.fuenf (0.5.4) (C) by Jrgen Grneisl
// Visit me on http://www.tv-kritik.net/mgb/index.php
//
// This Guestbook is licensed under GNU GPL. Feel free to use, copy, share or modify it. :)

         include "settings.php";
         include "language/lang_admin.php";
         include "language/lang_main.php";

         if($_GET[sn]==""){$_GET[sn]=1;}

if($_GET[sid]!=$settings['passwort'])
        	{
         $ausgabe="<br>\n";
         $ausgabe.="<br>\n";
         $ausgabe.="<center>\n";
         $ausgabe.="<table summary='deaktivieren' class='passwort' cellspacing='0' cellpadding='5'>\n";
         $ausgabe.="<tr>\n";
         $ausgabe.="<td class='passworteingabetitel' style='height:20px'><font class='passworteingabetitel'>".$lang['failure']."</font></td>\n";
         $ausgabe.="</tr>\n";
         $ausgabe.="<tr>\n";
         $ausgabe.="<td class='passworteingabe'>\n";
         $ausgabe.="<center>\n";
         if($_POST[passwort]!="")
         	{
                 $ausgabe.="<br><font class='passwort_fehler'><b>".$lang['changed_pw']."</b></font><br><br>";
                 }
         else
         	{
         	$ausgabe.="<br><font class='passwort_fehler'><b>".$lang['not_logged_in']."</b></font><br><br>";
                 }
         $ausgabe.="</center>\n";
         $ausgabe.="</td>\n";
         $ausgabe.="</tr>\n";
         $ausgabe.="</table>\n";
         $ausgabe.="<br>\n";
         $ausgabe.="<br>\n";
         $ausgabe.="</center>\n";
         $anzeige[0]=$ausgabe;
         }
else
	{
         include "config.php";

         if($_GET[action]=="deactivate")
         	{
                 $sql="UPDATE `$db[entrys]` SET `checked` = '-1' WHERE ID=".$_GET[id]." LIMIT 1";
	        $link=mysql_connect($db[host], $db[user], $db[password]) or die ("Keine Verbindung zur Datenbank mglich. Prfen Sie die Zugangsdaten.");
         	mysql_select_db($db[dbname], $link) or die ("Datenbankfehler");
	        $result=mysql_query($sql, $link) or die ("MySQL Fehler");
                 }

         // Auslesen der vorhandenen Eintr&auml;ge
         $sql="SELECT * FROM $db[entrys] WHERE checked=1 ORDER BY ID DESC";
         $link=mysql_connect($db[host], $db[user], $db[password]) or die ("Keine Verbindung zur Datenbank mglich. Prfen Sie die Zugangsdaten.");
         mysql_select_db($db[dbname], $link) or die ("Datenbankfehler");
         $result=mysql_query($sql, $link) or die ("MySQL Fehler");

         for($i=0;$i<mysql_num_rows($result);$i++)
         	{
		$eintrag[$i]=mysql_fetch_array($result);
		}

         $zaehler2=0;
         for($i=0;$i<count($eintrag);$i++)
         	{
                 $ausgabe="";
                	$ausgabe.="<br>\n<table summary='deaktivieren' cellspacing='0' cellpadding='3'>\n";
                	$ausgabe.="<tr>\n<td style='width:3%'><font><b>".$eintrag[$i][ID]."</b></font></td>\n";
                	$ausgabe.="<td style='width:57%;vertical-align:middle'><b><font>&nbsp;".$eintrag[$i][name];
                 if($eintrag[$i][place])
                 	{
                         $ausgabe.="&nbsp;".$lang['from']."&nbsp;".$eintrag[$i][place];
                         }
                 $ausgabe.="</font></b></td>\n<td align='right'><font>".$eintrag[$i][date]."&nbsp;".$lang['between_date_and_time']."&nbsp;".$eintrag[$i][time]."&nbsp;".$lang['time']."</font></td>\n</tr>\n";
                 $ausgabe.="<tr>\n<td colspan='3'><font>".$eintrag[$i][message]."</font></td>\n</tr>\n";
		$ausgabe.="<tr>\n<td colspan='3'>";
                 if($eintrag[$i][email])
                 	{
                         $ausgabe.="&nbsp;<a href='mailto:".$eintrag[$i][email]."'><img src='images/mail.png' border='0' alt='".$lang['alt_email_before_name']." ".$eintrag[$i][name]." ".$lang['alt_email_after_name']."' title='".$lang['alt_email_before_name']." ".$eintrag[$i][name]." ".$lang['alt_email_after_name']."'></a>\n";
                         }
                 if(strstr($eintrag[$i][hp],'http://'))
                 	{
                         $ausgabe.="&nbsp;<a href='".$eintrag[$i][hp]."' target='_blank'><img src='images/hp.png' border='0' alt='".$lang['alt_homepage_before_name']." ".$eintrag[$i][name]." ".$lang['alt_homepage_after_name']."' title='".$lang['alt_homepage_before_name']." ".$eintrag[$i][name]." ".$lang['alt_homepage_after_name']."'></a>\n";
                         }
                 if($eintrag[$i][icq]>=1)
                 	{
                         $ausgabe.="&nbsp;<a href='http://www.icq.com/".$eintrag[$i][icq]."' target='_blank'><img alt='ICQ# ".$eintrag[$i][icq]."' title='ICQ# ".$eintrag[$i][icq]."' style='height:15px;width:16px;border:none' src='images/icq.png'></a>\n";
                         }
                 if($eintrag[$i][aim])
                 	{
                         $ausgabe.="&nbsp;<a href='aim:goim?screenname=".$eintrag[$i][aim]."&amp;message=Hello+Are+you+there?' target='_blank'><img alt='AIM ".$eintrag[$i][aim]."' title='AIM ".$eintrag[$i][aim]."' style='height:15px;width:15px;border:none' src='images/aim.png'></a>\n";
                         }
                 if($eintrag[$i][msn])
                 	{
                         $ausgabe.="&nbsp;<a href='http://members.msn.com/?mem=".$eintrag[$i][msn]."' target='_blank'><img alt='MSN ".$eintrag[$i][msn]."' title='MSN ".$eintrag[$i][msn]."' style='height:15px;width:15px;border:none' src='images/msn.png'></a>\n";
                         }
                 $ausgabe.="&nbsp;&nbsp;<font><b>IP:&nbsp;".$eintrag[$i][ip]."</b></font></td>\n</tr>\n";
                 $ausgabe.="<tr>\n<td style='height:15px' colspan='3'>&nbsp;<font>&raquo;&nbsp;<a href='".$PHP_SELF."?action=deactivate&amp;id=".$eintrag[$i][ID]."&amp;sid=".$_GET[sid]."'>".$lang['deactivate_entry']."</a></font></td>\n</tr>\n";
                 $ausgabe.="</table><br>\n";
                 $anzeige[$zaehler2++]=$ausgabe;
                 }

	$seitenzahl = ceil($zaehler2/10);        // Anzahl der Seiten feststellen
         if($seitenzahl <= 1)
         	{
                 if($zaehler2 > 1)
                         {
                 	$counter = $zaehler2."&nbsp;".$lang['entrys'];
                         }
                 elseif($zaehler2 == 0)
                         {
                 	$counter = $zaehler2."&nbsp;".$lang['entrys'];
                         $anzeige[0]="<br><font>".$lang['no_entrys']."</font>";
                         }
                 else
                         {
                 	$counter = $zaehler2."&nbsp;".$lang['entry'];
                         }
                 }
         else
         	{
         	$counter = $zaehler2."&nbsp;".$lang['entrys_on_pages_before_counter']."&nbsp;".$seitenzahl."&nbsp;".$lang['entrys_on_pages_after_counter'];
                 }

         if($seitenzahl <= 5)        // Wenn weniger oder gleich 10 Eintr&auml;ge im G&auml;stebuch sind, keine Links anzeigen
         	{
		for($szahl=1;$szahl<=$seitenzahl;$szahl++)
                 	{
                         if($_GET[sn] == $szahl)
                         	{
                                 $seitenanzeige.="$szahl | ";        // Auf der angezeigten Seite die Nummer nicht als Link darstellen
                                 }
                         else
                         	{
                                 $seitenanzeige.="<a href='".$PHP_SELF."?sn=".$szahl."&amp;sid=".$_GET[sid]."'>".$szahl."</a> | ";	// Alle anderen Seiten als Link darstellen
                                 }
                         }
                 }
         else
         	{
                 if(!$_GET[next])
                 	{
			for($szahl=1;$szahl<=5;$szahl++)
                 		{
                         	if($_GET[sn] == $szahl)
                         		{
                                 	$seitenanzeige.="$szahl | ";        // Auf der angezeigten Seite die Nummer nicht als Link darstellen
                                 	}
                         	else
                         		{
                                 	$seitenanzeige.="<a href='".$PHP_SELF."?sn=".$szahl."&amp;sid=".$_GET[sid]."'>".$szahl."</a> | ";	// Alle anderen Seiten als Link darstellen
                                 	}
                         	}
                         $seitenanzeige.="<a href='".$PHP_SELF."?sn=6&amp;next=2&amp;sid=".$_GET[sid]."'>&raquo;</a> | ";
                         }
		else
                 	{
                         $nextstart = (($_GET[next] * 5)-4);
			if($_GET[next] == 2)
                         	{
                         	$seitenanzeige.="<a href='".$PHP_SELF."?sn=1&amp;sid=".$_GET[sid]."'>&laquo;</a> | ";
                                 }
                         else
                         	{
                                 $seitenanzeige.="<a href='".$PHP_SELF."?sn=".($_GET[sn] - 5)."&amp;next=".($_GET[next] - 1)."&amp;sid=".$_GET[sid]."'>&laquo;</a> | ";
                                 }
                         $nextend = ($seitenzahl - $nextstart);
                         if($nextend > 4){$nextend = 4;$onemorenext = 1;}
			for($szahl=$nextstart;$szahl<=($nextstart + $nextend);$szahl++)
                 		{
                         	if($_GET[sn] == $szahl)
                         		{
                                 	$seitenanzeige.="$szahl | ";        // Auf der angezeigten Seite die Nummer nicht als Link darstellen
                                 	}
                         	else
                         		{
                                 	$seitenanzeige.="<a href='".$PHP_SELF."?sn=".$szahl."&amp;next=".$_GET[next]."&amp;sid=".$_GET[sid]."'>".$szahl."</a> | ";	// Alle anderen Seiten als Link darstellen
                                 	}
                         	}
                         if($onemorenext == 1)
                         	{
                                 $seitenanzeige.="<a href='".$PHP_SELF."?sn=".((($_GET[next] + 1) * 5) - 4)."&amp;next=".($_GET[next] + 1)."&amp;sid=".$_GET[sid]."'>&raquo;</a> | ";
                                 }
                         }
                 }
         }
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<title>Administration - guestbook v.null.f&uuml;nf by mopzz.de</title>
<meta name="author" content="mopzz">
<meta name="keywords" content="mgb.v.null.fuenf, mopzz.de, kostenloses g&auml;stebuch, kostenloses php g&auml;stebuch">
<meta http-equiv="content-type" content="text/html; charset=ISO-8859-1">
<link rel="stylesheet" type="text/css" href="css/activate.css">
</head>
<body>
<center>
<?php
         if($_GET[sid]==$settings['passwort'])
         	{
         	echo "<font><b>".$zaehler2." ".$lang['active_entries']."</b></font><br>";
                 }

	if($zaehler2>10)        // Wenn weniger als 10 Eintr&auml;ge angezeigt werden, keine Seitenanzeige darstellen. Man w&uuml;rde sonst das | alleine sehen.
                 {
                 echo "<br><center><font>| ".$seitenanzeige."</font></center>";
                 }

         if(!$_GET[sn])	// Wenn nur guestbook.php ohne ?sn=$szahl aufgerufen wird, den Startwert auf 0 setzen
                 {
                 $startwert=0;
                 }
         elseif($_GET[sn]==1)	// Wenn die erste Seite angezeigt wird, den Startwert ebenfalls auf 0 setzen
                 {
                 $startwert=0;
                 }
         else			// Wenn "sn" nicht 1 ist, den Wert mit 10 multiplizieren und 10 abziehen um vom ersten Eintrag in diesem Datensatz aus zu starten.
                 {
                 $startwert=(($_GET[sn]*10)-10);
                 }
         for($zahl=$startwert;$zahl<=($startwert+9);$zahl++)	// vom ersten Eintrag bis zum letzten in diesem Datensatz hochz&auml;hlen und ausgeben
                 {
                 echo $anzeige[$zahl];
                 }
         if($zaehler2>10)	// Wenn weniger als 10 Eintr&auml;ge angezeigt werden, keine Seitenanzeige darstellen. Man w&uuml;rde sonst das | alleine sehen.
                 {
                 echo "<br><center><font>| ".$seitenanzeige."</font></center>";
                 }
?>
</center>
</body>
</html>
